@@ -1,7 +1,7 @@
 //
 //  Mixer.app
 // 
-//  Copyright (c) 1998 Per Liden
+//  Copyright (c) 1998, 1999 Per Liden
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,8 @@
 
 #include "Mixer.h"
 
-
-int main(int argc, char** argv)
-{
+int main(int argc, char** argv) {
     Mixer app(argc, argv);
-    app.Run();
+    app.run();
     return 0;
 }
-
-
