@@ -1,7 +1,7 @@
 //
 //  Mixer.app
 // 
-//  Copyright (c) 1998 Per Liden
+//  Copyright (c) 1998, 1999 Per Liden
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -19,36 +19,26 @@
 //  USA.
 //
 
-#ifndef _Xpm_h_
-#define _Xpm_h_
+#ifndef _XPM_H_
+#define _XPM_H_
 
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
-#include <X11/extensions/shape.h>
-#include <iostream.h>
-#include "Mixer.h"
 
-extern Display* Dpy;
-extern Window Root;
-
-
-class Xpm
-{
-public:
-    Xpm(char** xpmdata);
+class Xpm {
+ public:
+    Xpm(Display* display, Window root, char** data);
     virtual ~Xpm();
-    void SetWindowPixmap(Window win);
-    void SetWindowPixmapShaped(Window win);
+    void setWindowPixmap(Window win);
+    void setWindowPixmapShaped(Window win);
 
-private:
-    Xpm();		// Disabled constructor
+ private:
+    Xpm();  // Disabled constructor
 
-    // Pixmap data
-    Pixmap Image;
-    Pixmap Mask;
-    XpmAttributes Attributes;
+    Display*      mDisplay;
+    XpmAttributes mAttributes;
+    Pixmap        mImage;
+    Pixmap        mMask;
 };
 
-
 #endif
-
